@@ -1,15 +1,15 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-g-save_process.php,v 1.5.2.1 2005/01/01 00:11:24 damosoft Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-g-save_process.php,v 1.9 2007-10-12 07:55:27 nyloth Exp $
 
-// Copyright (c) 2002-2005, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 require_once ('tiki-setup.php');
 
 include_once ('lib/Galaxia/ProcessManager.php');
 
-if ($feature_workflow != 'y') {
+if ($prefs['feature_workflow'] != 'y') {
 	die;
 }
 
@@ -21,7 +21,7 @@ if ($tiki_p_admin_workflow != 'y') {
 
 /*
 // Check if feature is enabled and permissions
-if($feature_galaxia != 'y') {
+if($prefs['feature_galaxia'] != 'y') {
   $smarty->assign('msg',tra("This feature is disabled"));
   $smarty->display("error.tpl");
   die;  
@@ -38,4 +38,4 @@ echo ('<?xml version="1.0"?>');
 $data = $processManager->serialize_process($_REQUEST['pid']);
 echo $data;
 
-?>
\ No newline at end of file
+?>
